@@ -498,7 +498,7 @@ sub configure_relocatability {
 sub configure_repo_urls {
     my $self = shift;
 
-    # Pre-cache repo urls to make them available for makefiles.
+    # Pre-cach repo urls to make them available for makefiles.
     for my $r ( keys %{ $self->{repo_maps} } ) {
         $self->repo_url( $r, action => 'pull' );
         $self->repo_url( $r, action => 'push' );
@@ -666,7 +666,7 @@ sub configure_from_options {
     for my $opt (
         qw<prefix rakudo-home nqp-home sdkroot sysroot github-user git-protocol
         rakudo-repo nqp-repo moar-repo roast-repo makefile-timing
-        relocatable git-cache-dir>
+        relocatable reference>
       )
     {
         ( my $ckey = $opt ) =~ s/-/_/g;
@@ -680,12 +680,6 @@ sub configure_from_options {
         $config->{"opt_$cf_var"} = $opt_val;
     }
 
-    if ( $self->{options}{'git-reference'} ) {
-        print "===WARNING!===\n";
-        print "The --git-reference option does not exist anymore.\n";
-        print "Consider using --git-cache-dir instead.\n";
-    }
-
     $config->{stagestats} = '--stagestats'
       if $self->{options}{'makefile-timing'};
 
@@ -1084,9 +1078,13 @@ sub fill_template_text {
 }
 
 sub reference_dir {
-    my ($self, $name) = @_;
-    my $git_cache_dir = $self->cfg('git_cache_dir');
-    return File::Spec->catdir( $git_cache_dir, $name );
+    my $self      = shift;
+    my $reference = $self->cfg('reference');
+    for my $d (@_) {
+        my $dir = File::Spec->catdir( $reference, $d );
+        return $dir if -d $dir;
+    }
+    return '';
 }
 
 sub git_checkout {
@@ -1098,34 +1096,18 @@ sub git_checkout {
     my $config  = $self->config;
     my $options = $self->{options};
     my $pwd     = cwd();
-    my $pullurl = $self->repo_url( $repo, action => 'pull' );
-    my $pushurl = $self->repo_url( $repo, action => 'push' );
 
-    # Clone / fetch git reference repo
-    if ( $config->{git_cache_dir} ) {
-        my $ref_dir =
-          $self->reference_dir( $self->{repo_maps}{$repo}[1] );
-        if ( !-d $ref_dir ) {
-            my @ref_args = ( 'git', 'clone', '--bare' );
-            push @ref_args, "--depth=$options->{'git-depth'}"
-              if $options->{'git-depth'};
-            push @ref_args, $pullurl, $ref_dir;
-            $self->msg("Cloning reference from $pullurl\n");
-            system_or_die(@ref_args);
-        }
-        else {
-            chdir($ref_dir);
-            system_or_die( 'git', 'fetch' );
-            chdir($pwd);
-        }
-    }
     # get an up-to-date repository
     if ( !-d $dir ) {
+        my ( $pullurl, $pushurl ) = (
+            $self->repo_url( $repo, action => 'pull' ),
+            $self->repo_url( $repo, action => 'push' ),
+        );
         my @args = ( 'git', 'clone' );
-        if ( $config->{git_cache_dir} ) {
+        if ( $config->{reference} ) {
             my $ref_dir =
-              $self->reference_dir( $self->{repo_maps}{$repo}[1] );
-            die "Can't find $repo reference directory in $config->{git_cache_dir}"
+              $self->reference_dir( $self->{repo_maps}{$repo}[1], $dir );
+            die "Can't $repo repository directory in $config->{reference}"
               unless $ref_dir;
             push @args, "--reference=$ref_dir";
         }
