@@ -21,22 +21,15 @@
 #define GET_REG(tc, idx)    (*tc->interp_reg_base)[*((MVMuint16 *)(cur_op + idx))]
 #define REAL_BODY(tc, obj)  MVM_p6opaque_real_data(tc, OBJECT_BODY(obj))
 
-/* Dummy zero and one-arg callsite. */
-static MVMCallsite      no_arg_callsite = { NULL, 0, 0, 0, 0 };
-static MVMCallsiteEntry one_arg_flags[] = { MVM_CALLSITE_ARG_OBJ };
-static MVMCallsite     one_arg_callsite = { one_arg_flags, 1, 1, 1, 0 };
+/* Dummy zero and one-str callsite. */
+static MVMCallsite      no_arg_callsite = { NULL, 0, 0, 0, 0, 0, NULL, NULL };
 static MVMCallsiteEntry one_str_flags[] = { MVM_CALLSITE_ARG_STR };
-static MVMCallsite     one_str_callsite = { one_str_flags, 1, 1, 1, 0 };
-
-/* Assignment type check failed callsite. */
-static MVMCallsiteEntry atcf_flags[] = { MVM_CALLSITE_ARG_STR, MVM_CALLSITE_ARG_OBJ, 
-                                         MVM_CALLSITE_ARG_OBJ };
-static MVMCallsite     atcf_callsite = { atcf_flags, 3, 3, 3, 0 };
+static MVMCallsite     one_str_callsite = { one_str_flags, 1, 1, 1, 0, 0, NULL, NULL };
 
 /* Dispatcher vivify_for callsite. */
 static MVMCallsiteEntry disp_flags[] = { MVM_CALLSITE_ARG_OBJ, MVM_CALLSITE_ARG_OBJ, 
                                          MVM_CALLSITE_ARG_OBJ, MVM_CALLSITE_ARG_OBJ };
-static MVMCallsite     disp_callsite = { disp_flags, 4, 4, 4, 0 };
+static MVMCallsite     disp_callsite = { disp_flags, 4, 4, 4, 0, 0, NULL, NULL };
 
 /* Are we initialized yet? */
 static int initialized = 0;
@@ -65,8 +58,8 @@ static void p6init(MVMThreadContext *tc, MVMuint8 *cur_op) {
         MVM_gc_root_add_permanent_desc(tc, (MVMCollectable **)&str_dispatcher, "$*DISPATCHER");
         str_vivify_for = MVM_string_ascii_decode_nt(tc, tc->instance->VMString, "vivify_for");
         MVM_gc_root_add_permanent_desc(tc, (MVMCollectable **)&str_vivify_for, "vivify_for");
-        str_perl6 = MVM_string_ascii_decode_nt(tc, tc->instance->VMString, "perl6");
-        MVM_gc_root_add_permanent_desc(tc, (MVMCollectable **)&str_perl6, "perl6");
+        str_perl6 = MVM_string_ascii_decode_nt(tc, tc->instance->VMString, "Raku");
+        MVM_gc_root_add_permanent_desc(tc, (MVMCollectable **)&str_perl6, "Raku");
         str_p6ex = MVM_string_ascii_decode_nt(tc, tc->instance->VMString, "P6EX");
         MVM_gc_root_add_permanent_desc(tc, (MVMCollectable **)&str_p6ex, "P6EX");
         str_xnodisp = MVM_string_ascii_decode_nt(tc, tc->instance->VMString, "X::NoDispatcher");
